aboutsummaryrefslogtreecommitdiffstats
path: root/mod/profile_photo.php
diff options
context:
space:
mode:
authorfriendica <info@friendica.com>2012-07-17 16:02:16 -0700
committerfriendica <info@friendica.com>2012-07-17 16:02:16 -0700
commit073eb1b8455fe93e49a95125cb23c8d8accb96e2 (patch)
tree1633d6835a42c38d6a59573b49e8c50b11fee664 /mod/profile_photo.php
parent359c74d320eef7fad24a30b677522a428affe509 (diff)
downloadvolse-hubzilla-073eb1b8455fe93e49a95125cb23c8d8accb96e2.tar.gz
volse-hubzilla-073eb1b8455fe93e49a95125cb23c8d8accb96e2.tar.bz2
volse-hubzilla-073eb1b8455fe93e49a95125cb23c8d8accb96e2.zip
backend support for alternate profile photos for private profiles
Diffstat (limited to 'mod/profile_photo.php')
-rw-r--r--mod/profile_photo.php45
1 files changed, 36 insertions, 9 deletions
diff --git a/mod/profile_photo.php b/mod/profile_photo.php
index fc0e0419e..efa8be57e 100644
--- a/mod/profile_photo.php
+++ b/mod/profile_photo.php
@@ -24,6 +24,20 @@ function profile_photo_post(&$a) {
if((x($_POST,'cropfinal')) && ($_POST['cropfinal'] == 1)) {
+ // unless proven otherwise
+ $is_default_profile = 1;
+
+ if($_REQUEST['profile']) {
+ $r = q("select id, `is-default` from profile where id = %d and uid = %d limit 1",
+ intval($_REQUEST['profile']),
+ intval(local_user())
+ );
+ if(count($r) && (! intval($r[0]['is-default'])))
+ $is_default_profile = 0;
+ }
+
+
+
// phase 2 - we have finished cropping
if($a->argc != 2) {
@@ -57,31 +71,44 @@ function profile_photo_post(&$a) {
if($im->is_valid()) {
$im->cropImage(175,$srcX,$srcY,$srcW,$srcH);
- $r = $im->store(local_user(), 0, $base_image['resource-id'],$base_image['filename'], t('Profile Photos'), 4, 1);
+ $r = $im->store(local_user(), 0, $base_image['resource-id'],$base_image['filename'], t('Profile Photos'), 4, $is_default_profile);
if($r === false)
notice ( sprintf(t('Image size reduction [%s] failed.'),"175") . EOL );
$im->scaleImage(80);
- $r = $im->store(local_user(), 0, $base_image['resource-id'],$base_image['filename'], t('Profile Photos'), 5, 1);
+ $r = $im->store(local_user(), 0, $base_image['resource-id'],$base_image['filename'], t('Profile Photos'), 5, $is_default_profile);
if($r === false)
notice( sprintf(t('Image size reduction [%s] failed.'),"80") . EOL );
$im->scaleImage(48);
- $r = $im->store(local_user(), 0, $base_image['resource-id'],$base_image['filename'], t('Profile Photos'), 6, 1);
+ $r = $im->store(local_user(), 0, $base_image['resource-id'],$base_image['filename'], t('Profile Photos'), 6, $is_default_profile);
if($r === false)
notice( sprintf(t('Image size reduction [%s] failed.'),"48") . EOL );
- // Unset the profile photo flag from any other photos I own
-
- $r = q("UPDATE `photo` SET `profile` = 0 WHERE `profile` = 1 AND `resource-id` != '%s' AND `uid` = %d",
- dbesc($base_image['resource-id']),
- intval(local_user())
- );
+ // If setting for the default profile, unset the profile photo flag from any other photos I own
+
+ if($is_default_profile) {
+ $r = q("UPDATE `photo` SET `profile` = 0 WHERE `profile` = 1 AND `resource-id` != '%s' AND `uid` = %d",
+ dbesc($base_image['resource-id']),
+ intval(local_user())
+ );
+ }
+ else {
+ $r = q("update profile set photo = '%s', thumb = '%s' where id = %d and uid = %d limit 1",
+ dbesc($a->get_baseurl() . '/photo/' . $base_image['resource-id'] . '-4'),
+ dbesc($a->get_baseurl() . '/photo/' . $base_image['resource-id'] . '-5'),
+ intval($_REQUEST['profile']),
+ intval(local_user())
+ );
+ }
+
+ // we'll set the updated profile-photo timestamp even if it isn't the default profile,
+ // so that browsers will do a cache update unconditionally
$r = q("UPDATE `contact` SET `avatar-date` = '%s' WHERE `self` = 1 AND `uid` = %d LIMIT 1",
dbesc(datetime_convert()),